Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GetEthClient ¶
func GetEthClient(ctx context.Context, container testcontainers.Container) (*ethclient.Client, error)
GetEthClient returns an Ethereum client connected to the container
func HTTPEndpoint ¶
HTTPEndpoint returns the HTTP endpoint URL for the container
Types ¶
type Account ¶
type Account struct {
Address common.Address
PrivateKey *ecdsa.PrivateKey
}
Account represents an Ethereum account with its address and private key
func GetPreFundedAccounts ¶
func GetPreFundedAccounts(ctx context.Context, container testcontainers.Container) ([]Account, error)
GetPreFundedAccounts returns a set of pre-funded Ethereum accounts in Ganache
Click to show internal directories.
Click to hide internal directories.